@@ -64,13 +64,13 @@ struct _FontSetting {
     //gsettings
     GSettings * g_interface;
     GSettings * g_marco;
-    GSettings * g_caja;
+    GSettings * g_peony;
 };
 FontSetting fontsetting;
 gint default_font;
 gint default_document_font;
 gint default_monospace_font;
-gint default_caja_font;
+gint default_peony_font;
 gint default_title_font;
 //for example, mate
 typedef struct _FontInfo FontInfo;
@@ -79,7 +79,7 @@ struct _FontInfo{
     char * font_name; // org.mate.interface font-name
     char * document_font_name; //org.mate.interface document-font-name
     char * monospace_font_name; //org.mate.interface monospace-font-name
-    char * font; //org.mate.caja.desktop font
+    char * font; //org.mate.peony.desktop font
     char * titlebar_font; //org.mate.Marco.general
 };
 //fill struct
@@ -96,7 +96,7 @@ FontInfo fontinfo[N] = {
     "Ubuntu Mono",
     "Sans",
     "Ubuntu Bold"},
-	{"Kylin",
+	{"Ukui",
 	"Ubuntu",
 	"Ubuntu",
 	"Ubuntu Mono",
@@ -169,8 +169,8 @@ static void set_gsetting(){
             g_sprintf(fontstring, "%s %d",fontinfo[i].monospace_font_name,(gint)(default_monospace_font * fontsetting.level));
             g_settings_set_string(fontsetting.g_interface,MONOSPACE_FONT_KEY,fontstring);
 
-            g_sprintf(fontstring, "%s %d",fontinfo[i].font,(gint)(default_caja_font * fontsetting.level));
-            g_settings_set_string(fontsetting.g_caja,DESKTOP_FONT_KEY,fontstring);
+            g_sprintf(fontstring, "%s %d",fontinfo[i].font,(gint)(default_peony_font * fontsetting.level));
+            g_settings_set_string(fontsetting.g_peony,DESKTOP_FONT_KEY,fontstring);
 
             g_sprintf(fontstring, "%s %d",fontinfo[i].titlebar_font, (gint)(default_title_font * fontsetting.level));
             g_settings_set_string(fontsetting.g_marco,WINDOW_TITLE_FONT_KEY,fontstring);
@@ -235,7 +235,7 @@ static void init_font_info(){
     current_info.font_name =get_string(g_settings_get_string(fontsetting.g_interface, GTK_FONT_KEY),0);
     current_info.document_font_name = get_string(g_settings_get_string(fontsetting.g_interface, DOCUMENT_FONT_KEY),1);
     current_info.monospace_font_name = get_string(g_settings_get_string(fontsetting.g_interface, MONOSPACE_FONT_KEY),0);
-    current_info.font = get_string(g_settings_get_string(fontsetting.g_caja, DESKTOP_FONT_KEY),0);
+    current_info.font = get_string(g_settings_get_string(fontsetting.g_peony, DESKTOP_FONT_KEY),0);
     current_info.titlebar_font =get_string(g_settings_get_string(fontsetting.g_marco, WINDOW_TITLE_FONT_KEY),0);
     for(i=0; i<N;i++){
         if(g_strcmp0(fontinfo[i].font_name, current_info.font_name) != 0)
@@ -278,9 +278,9 @@ static void init_font_data(){
     while (valid){
         gtk_tree_model_get(treemodel, &iter,0, &name, -1);
         if (g_strcmp0(name, fontsetting.font_name) == 0){
-			g_signal_handlers_block_by_func(fontsetting.font_select_combo, font_select_changed, NULL);
+	    g_signal_handlers_block_by_func(fontsetting.font_select_combo, font_select_changed, NULL);
             gtk_combo_box_set_active_iter(GTK_COMBO_BOX(fontsetting.font_select_combo), &iter);
-			g_signal_handlers_unblock_by_func(fontsetting.font_select_combo, font_select_changed, NULL);
+	    g_signal_handlers_unblock_by_func(fontsetting.font_select_combo, font_select_changed, NULL);
             valid = FALSE;
         }
         else {
@@ -327,14 +327,14 @@ static void get_default_setting(AppearanceData *data){
 		default_monospace_font = atoi(&font_value[length -2]);
 	g_variant_unref(value);
 	
-	value = g_settings_get_default_value(data->caja_settings, DESKTOP_FONT_KEY);
+	value = g_settings_get_default_value(data->peony_settings, DESKTOP_FONT_KEY);
 	size = g_variant_get_size(value);
 	font_value = g_variant_get_string(value, &size);
 	length = (gint)strlen(font_value);
 	if (font_value[length -2] == ' ')
-		default_caja_font = atoi(&font_value[length -1]);
+		default_peony_font = atoi(&font_value[length -1]);
 	else
-		default_caja_font = atoi(&font_value[length -2]);
+		default_peony_font = atoi(&font_value[length -2]);
 	g_variant_unref(value);
 	
 	value = g_settings_get_default_value(data->marco_settings, WINDOW_TITLE_FONT_KEY);
@@ -475,12 +475,10 @@ static void set_fontoptions(PangoContext *context, Antialiasing antialiasing, Hi
 static void setup_font_sample(GtkWidget * darea, Antialiasing antialiasing, Hinting hinting){
     const char * string1;
     char *lang = getenv("LANG");
-    if (strncmp(lang, "zh_CN", 5) == 0)
-        string1 = "欢迎使用UKUI桌面环境";
+    if (!lang || strncmp(lang, "zh_CN", 5))
+        string1 = "Welcome to UKUI";
     else
-        string1 = "Welcome to Linux";
-
-    const char * string2 = "Welcome to Kylin";
+        string1 = "欢迎使用UKUI桌面环境";
 
     PangoContext *context;
     PangoLayout *layout;
@@ -518,7 +516,17 @@ static void setup_font_sample(GtkWidget * darea, Antialiasing antialiasing, Hint
     g_signal_connect(darea, "draw", G_CALLBACK(sample_draw), NULL);
 }
 
+//通过设置字体的的sensitive属性，结合css，实现给所选字体设置背景色
+static void init_font_sensitive(){
+    gtk_widget_set_sensitive(fontsetting.monochrome_button, TRUE);
+    gtk_widget_set_sensitive(fontsetting.best_contrast_button, TRUE);
+    gtk_widget_set_sensitive(fontsetting.best_shapes_button, TRUE);
+    gtk_widget_set_sensitive(fontsetting.subpixel_button, TRUE);
+}
+
 static void font_button_clicked(GtkButton *button, FontPair *pair){
+    init_font_sensitive();
+    gtk_widget_set_sensitive(GTK_WIDGET(button), FALSE);
     GSettings * settings = g_settings_new(FONT_RENDER_SCHEMA);
     g_settings_set_enum(settings, FONT_ANTIALIASING_KEY, pair->antialiasing);
     g_settings_set_enum(settings, FONT_HINTING_KEY, pair->hinting);
@@ -532,6 +540,13 @@ static void setup_font_pair(GtkWidget * button, GtkWidget * darea, Antialiasing
     pair->hinting = hinting;
     pair->button = button;
 
+    GSettings *settings = g_settings_new(FONT_RENDER_SCHEMA);
+    int current_antialiasing = g_settings_get_enum(settings, FONT_ANTIALIASING_KEY);
+    int current_hinting = g_settings_get_enum(settings, FONT_HINTING_KEY);
+    if (current_antialiasing == antialiasing && current_hinting == hinting)
+	    gtk_widget_set_sensitive(GTK_WIDGET(button), FALSE);
+    g_object_unref(settings);
+
     setup_font_sample(darea, antialiasing, hinting);
     font_pairs = g_slist_prepend(font_pairs, pair);
     g_signal_connect(GTK_BUTTON(button), "clicked", G_CALLBACK(font_button_clicked), pair);
@@ -568,13 +583,14 @@ static gboolean reset_font_default(GtkWidget * widget, GdkEvent *event, gpointer
     g_settings_reset(fontsetting.g_interface, GTK_FONT_KEY);
     g_settings_reset(fontsetting.g_interface, MONOSPACE_FONT_KEY);
     g_settings_reset(fontsetting.g_marco,WINDOW_TITLE_FONT_KEY);
-    g_settings_reset(fontsetting.g_caja, DESKTOP_FONT_KEY);
+    g_settings_reset(fontsetting.g_peony, DESKTOP_FONT_KEY);
     init_font_info();
     init_font_data();
     //reset  font render
     GSettings * settings = g_settings_new(FONT_RENDER_SCHEMA);
     g_settings_reset(settings,FONT_ANTIALIASING_KEY);
     g_settings_reset(settings,FONT_HINTING_KEY);
+    init_font_sensitive();
     g_object_unref(settings);
 }
 
@@ -588,7 +604,7 @@ void font_init(AppearanceData * data){
 
     fontsetting.g_interface = data->interface_settings;
     fontsetting.g_marco = data->marco_settings;
-    fontsetting.g_caja = data->caja_settings;
+    fontsetting.g_peony = data->peony_settings;
 
     GtkWidget *label33 = GTK_WIDGET(gtk_builder_get_object(fontsetting.builder, "label33"));
     GtkWidget *label31 = GTK_WIDGET(gtk_builder_get_object(fontsetting.builder, "label31"));
