@@ -36,7 +36,7 @@
 #define MOBILITY_KEY          "exec"
 #define MOBILITY_STARTUP_KEY  "startup"
 
-typedef struct _MateDACapplet 
+typedef struct _UkuiDACapplet 
 {
 	//combo box
 	GtkWidget* web_combo_box;
@@ -68,9 +68,9 @@ typedef struct _MateDACapplet
 	GSettings * mobility_settings;
 
 	GtkIconTheme * icon_theme;
-}MateDACapplet;
+}UkuiDACapplet;
 
-MateDACapplet * capplet;
+UkuiDACapplet * capplet;
 
 enum {
 	DA_TYPE_WEB_BROWSER,
@@ -96,7 +96,7 @@ enum {
 };
 
 static void 
-set_changed(GtkComboBox* combo, MateDACapplet* capplet, GList* list, gint type)
+set_changed(GtkComboBox* combo, UkuiDACapplet* capplet, GList* list, gint type)
 {
 	guint index;
 	GAppInfo* item;
@@ -115,6 +115,7 @@ set_changed(GtkComboBox* combo, MateDACapplet* capplet, GList* list, gint type)
 				g_app_info_set_as_default_for_type(item, "x-scheme-handler/https", NULL);
 				/* about:config is used by firefox and others */
 				g_app_info_set_as_default_for_type(item, "x-scheme-handler/about", NULL);
+				g_app_info_set_as_default_for_type(item, "text/html", NULL);
 				break;
 
 			case DA_TYPE_EMAIL:
@@ -181,61 +182,61 @@ set_changed(GtkComboBox* combo, MateDACapplet* capplet, GList* list, gint type)
 
 /* Combo boxes callbacks */
 static void
-web_combo_changed_cb(GtkComboBox* combo, MateDACapplet* capplet)
+web_combo_changed_cb(GtkComboBox* combo, UkuiDACapplet* capplet)
 {
 	set_changed(combo, capplet, capplet->web_browsers, DA_TYPE_WEB_BROWSER);
 }
 
 static void
-mail_combo_changed_cb(GtkComboBox* combo, MateDACapplet* capplet)
+mail_combo_changed_cb(GtkComboBox* combo, UkuiDACapplet* capplet)
 {
 	set_changed(combo, capplet, capplet->mail_readers, DA_TYPE_EMAIL);
 }
 
 static void
-file_combo_changed_cb(GtkComboBox* combo, MateDACapplet* capplet)
+file_combo_changed_cb(GtkComboBox* combo, UkuiDACapplet* capplet)
 {
 	set_changed(combo, capplet, capplet->file_managers, DA_TYPE_FILE);
 }
 
 static void
-text_combo_changed_cb(GtkComboBox* combo, MateDACapplet* capplet)
+text_combo_changed_cb(GtkComboBox* combo, UkuiDACapplet* capplet)
 {
 	set_changed(combo, capplet, capplet->text_editors, DA_TYPE_TEXT);
 }
 
 static void
-media_combo_changed_cb(GtkComboBox* combo, MateDACapplet* capplet)
+media_combo_changed_cb(GtkComboBox* combo, UkuiDACapplet* capplet)
 {
 	set_changed(combo, capplet, capplet->media_players, DA_TYPE_MEDIA);
 }
 
 static void
-video_combo_changed_cb(GtkComboBox* combo, MateDACapplet* capplet)
+video_combo_changed_cb(GtkComboBox* combo, UkuiDACapplet* capplet)
 {
 	set_changed(combo, capplet, capplet->video_players, DA_TYPE_VIDEO);
 }
 
 /*static void
-terminal_combo_changed_cb(GtkComboBox* combo, MateDACapplet* capplet)
+terminal_combo_changed_cb(GtkComboBox* combo, UkuiDACapplet* capplet)
 {
 	set_changed(combo, capplet, capplet->terminals, DA_TYPE_TERMINAL);
 }*/
 
 static void
-visual_combo_changed_cb(GtkComboBox* combo, MateDACapplet* capplet)
+visual_combo_changed_cb(GtkComboBox* combo, UkuiDACapplet* capplet)
 {
 	set_changed(combo, capplet, capplet->visual_ats, DA_TYPE_VISUAL);
 }
 
 static void
-mobility_combo_changed_cb(GtkComboBox* combo, MateDACapplet* capplet)
+mobility_combo_changed_cb(GtkComboBox* combo, UkuiDACapplet* capplet)
 {
 	set_changed(combo, capplet, capplet->mobility_ats, DA_TYPE_MOBILITY);
 }
 
 static void
-image_combo_changed_cb(GtkComboBox* combo, MateDACapplet* capplet)
+image_combo_changed_cb(GtkComboBox* combo, UkuiDACapplet* capplet)
 {
 	set_changed(combo, capplet, capplet->image_viewers, DA_TYPE_IMAGE);
 }
@@ -401,7 +402,19 @@ fill_combo_box(GtkIconTheme* theme, GtkComboBox* combo_box, GList* app_list, gch
 		}
 		g_free (default_mobility);
 		g_object_unref (mobility_settings);
-	}
+    }
+    //设置默认的文件管理器为peony,这样做是有问题的，每次打开控制面板都会将文件管理器设为peony
+    //但因为这里屏蔽掉了nautilus，只有一个文件管理器，先暂时这样
+    //正确的做法是修改系统配置来修改默认的应用
+    else if (g_strcmp0(mime, "inode/directory") == 0)
+    {
+        for (entry = app_list; entry != NULL; entry = g_list_next(entry))
+        {
+            GAppInfo* item = (GAppInfo*) entry->data;
+            if(g_strcmp0(g_app_info_get_id(item), "peony-folder-handler.desktop") == 0)
+                default_app = item;
+        }
+    }
 	else
 	{
 		default_app = g_app_info_get_default_for_type (mime, FALSE);
@@ -418,7 +431,8 @@ fill_combo_box(GtkIconTheme* theme, GtkComboBox* combo_box, GList* app_list, gch
 	renderer = gtk_cell_renderer_pixbuf_new();
 
 	/* Not all cells have a pixbuf, this prevents the combo box to shrink */
-	gtk_cell_renderer_set_fixed_size(renderer, -1, -1);
+    //这里指定宽度，是为了防止读不到正确尺寸的图标时而导致下拉框变宽
+    gtk_cell_renderer_set_fixed_size(renderer, -1, 26);
 	gtk_cell_layout_pack_start(GTK_CELL_LAYOUT(combo_box), renderer, FALSE);
 	gtk_cell_layout_set_attributes(GTK_CELL_LAYOUT(combo_box), renderer,
 				       "pixbuf", PIXBUF_COL,
@@ -437,12 +451,15 @@ fill_combo_box(GtkIconTheme* theme, GtkComboBox* combo_box, GList* app_list, gch
 		/* Icon */
 		GIcon* icon = g_app_info_get_icon(item);
 		gchar* icon_name = g_icon_to_string(icon);
-                if(strcmp(g_app_info_get_id(item), "org.gnome.Nautilus.desktop") == 0)
-                        continue;
-                //因为浏览器的desktop文件的图标路径不是相对路径，所以稍作转换。
-                if(g_strrstr(icon_name,"webbrowser")){
-                        icon_name = g_strdup("webbrowser-app");
-                }
+        if(g_strcmp0(g_app_info_get_id(item), "org.gnome.Nautilus.desktop") == 0
+                || g_strcmp0(g_app_info_get_id(item), "org.gnome.baobab.desktop") == 0
+                || g_strcmp0(g_app_info_get_id(item), "nautilus-folder-handler.desktop") == 0
+                || g_strcmp0(g_app_info_get_id(item), "vim.desktop") == 0)
+            continue;
+        //因为浏览器的desktop文件的图标路径不是相对路径，所以稍作转换。
+        if(g_strrstr(icon_name,"webbrowser")){
+            icon_name = g_strdup("webbrowser-app");
+        }
 		if (icon_name == NULL)
 		{
 			/* Default icon */
@@ -472,11 +489,11 @@ fill_combo_box(GtkIconTheme* theme, GtkComboBox* combo_box, GList* app_list, gch
 		}
 		/* Set the index for the default app */
 		//if (default_app != NULL && g_app_info_equal(item, default_app))
-                if (default_app != NULL && !strcmp(g_app_info_get_name(item), g_app_info_get_name(default_app)))
-		{
-			//g_warning("text_col=%s\tid_col=%s\ticon_name=%s\n",g_app_info_get_display_name(item), g_app_info_get_id(item),icon_name);
-			gtk_combo_box_set_active(combo_box, index);
-		}
+        if (default_app != NULL && !strcmp(g_app_info_get_name(item), g_app_info_get_name(default_app)))
+        {
+            //g_warning("text_col=%s\tid_col=%s\ticon_name=%s\n",g_app_info_get_display_name(item), g_app_info_get_id(item),icon_name);
+            gtk_combo_box_set_active(combo_box, index);
+        }
 		if (pixbuf)
 		{
 			g_object_unref(pixbuf);
@@ -564,7 +581,7 @@ void show_dialog(GtkBuilder * builder)
 void add_default_app(GtkBuilder * builder)
 {
 	g_debug("add_default_app");
-	capplet = g_new0(MateDACapplet, 1);
+	capplet = g_new0(UkuiDACapplet, 1);
 	capplet->terminal_settings = g_settings_new (TERMINAL_SCHEMA);
 	capplet->mobility_settings = g_settings_new (MOBILITY_SCHEMA);
 	capplet->visual_settings = g_settings_new (VISUAL_SCHEMA);
