@@ -103,7 +103,7 @@ kpm_brightness_helper_get_value (const gchar *argument)
 	gchar *command = NULL;
 
 	/* get the data */
-	command = g_strdup_printf (SBINDIR "/mate-power-backlight-helper --%s", argument);
+	command = g_strdup_printf (SBINDIR "/ukui-power-backlight-helper --%s", argument);
 	ret = g_spawn_command_line_sync (command,
 					 &stdout_data, NULL, &exit_status, &error);
 	if (!ret) 
@@ -136,7 +136,7 @@ kpm_brightness_helper_set_value (const gchar *argument, gint value)
 	gchar *command = NULL;
 
 	/* get the data */
-	command = g_strdup_printf ("pkexec " SBINDIR "/mate-power-backlight-helper --%s %i", argument, value);
+	command = g_strdup_printf ("pkexec " SBINDIR "/ukui-power-backlight-helper --%s %i", argument, value);
 	ret = g_spawn_command_line_sync (command, NULL, NULL, &exit_status, &error);
 	if (!ret) 
 	{
