@@ -530,8 +530,6 @@ prefs_setup_battery (KpmPrefs *prefs)
                 //return;
 				set_insensitive(prefs, "combobox_battery_computer");
 				set_insensitive(prefs, "combobox_battery_display");
-				set_insensitive(prefs, "combobox_general_power");
-				set_insensitive(prefs, "combobox_general_suspend");
 				//set_insensitive(prefs, "combobox_ac_lid");
 				set_insensitive(prefs, "combobox_battery_lid");
         }
@@ -645,9 +643,9 @@ prefs_setup_notification (KpmPrefs *prefs)
         gint icon_policy;
         GtkWidget *radiobutton_icon_always;
         GtkWidget *radiobutton_icon_present;
-        GtkWidget *radiobutton_icon_charge;
-        GtkWidget *radiobutton_icon_low;
-        GtkWidget *radiobutton_icon_never;
+//        GtkWidget *radiobutton_icon_charge;
+//        GtkWidget *radiobutton_icon_low;
+//        GtkWidget *radiobutton_icon_never;
         gboolean is_writable;
 
         icon_policy = g_settings_get_enum (prefs->priv->settings, KPM_SETTINGS_ICON_POLICY);
@@ -656,12 +654,12 @@ prefs_setup_notification (KpmPrefs *prefs)
                                                   "radiobutton_notification_always"));
         radiobutton_icon_present = GTK_WIDGET (gtk_builder_get_object (prefs->priv->builder,
                                                    "radiobutton_notification_present"));
-        radiobutton_icon_charge = GTK_WIDGET (gtk_builder_get_object (prefs->priv->builder,
-                                                  "radiobutton_notification_charge"));
-        radiobutton_icon_low = GTK_WIDGET (gtk_builder_get_object (prefs->priv->builder,
-                                           "radiobutton_notification_low"));
-        radiobutton_icon_never = GTK_WIDGET (gtk_builder_get_object (prefs->priv->builder,
-                                                 "radiobutton_notification_never"));
+//        radiobutton_icon_charge = GTK_WIDGET (gtk_builder_get_object (prefs->priv->builder,
+//                                                  "radiobutton_notification_charge"));
+//        radiobutton_icon_low = GTK_WIDGET (gtk_builder_get_object (prefs->priv->builder,
+//                                           "radiobutton_notification_low"));
+//        radiobutton_icon_never = GTK_WIDGET (gtk_builder_get_object (prefs->priv->builder,
+//                                                 "radiobutton_notification_never"));
 
         is_writable = g_settings_is_writable (prefs->priv->settings, KPM_SETTINGS_ICON_POLICY);
         gtk_widget_set_sensitive (radiobutton_icon_always, is_writable);
@@ -897,19 +895,6 @@ kpm_prefs_init (KpmPrefs *prefs)
     //prefs_setup_screensaver(prefs);
 	prefs_setup_battery (prefs);
 	prefs_setup_general (prefs);
-#if     defined(__aarch64__)
-	/*
-        GtkWidget *w =  GTK_WIDGET (gtk_builder_get_object (prefs->priv->builder, "label_battery"));
-        gtk_widget_hide(w);
-        GtkWidget *w2 =  GTK_WIDGET (gtk_builder_get_object (prefs->priv->builder, "vbox_battery"));
-        gtk_widget_hide(w2);
-		GtkWidget *w1 =  GTK_WIDGET (gtk_builder_get_object (prefs->priv->builder, "vbox25"));
-		gtk_widget_hide(w1);
-	*/
-#else
-    //prefs_setup_battery (prefs);
-    //prefs_setup_general (prefs);
-#endif
 	prefs_setup_notification (prefs);
 }
 
