@@ -447,7 +447,7 @@ static char * get_string_from_guint64(guint64 gu){
 }
 
 //example 1: Exec =/usr/bin/youker-assistant
-//example 2: Exec =mate-search-tool
+//example 2: Exec =ukui-search-tool
 //example 3: Exec =libreoffice --math
 //example 4: Exec =smplayer --add-to-playlist %U
 //and others example, like 1&3 1&4 ...
@@ -491,7 +491,7 @@ on_edit_app_clicked (GtkWidget           *widget,
         GtkDialog * pro_dialog;
         builder = gtk_builder_new();
         if (gtk_builder_add_from_file(builder, UIDIR"/program_properties.ui", &error ) == 0){
-            g_warning("Could not load ui file occured error:%s", error->message);
+            g_warning("Could not load ui file occurred error:%s", error->message);
             return;
         }
         edit_dialog = GTK_WIDGET(gtk_builder_get_object(builder, "dialog"));
@@ -735,17 +735,6 @@ setup_dialog (GsmPropertiesDialog *dialog)
                                               STORE_COL_DESCRIPTION,
                                               GTK_SORT_ASCENDING);
 
-        GtkWidget *title_vp = GTK_WIDGET(gtk_builder_get_object(dialog->priv->xml, "title_vp"));
-        GdkColor grey = {0,0xf0f0, 0xf0f0, 0xf0f0};
-        gtk_widget_modify_bg(title_vp, GTK_STATE_NORMAL, &grey);
-
-        GtkWidget *title_name = GTK_WIDGET(gtk_builder_get_object(dialog->priv->xml, "title_name"));
-        GtkWidget *title_status = GTK_WIDGET(gtk_builder_get_object(dialog->priv->xml, "title_status"));
-        GtkWidget *label54 = GTK_WIDGET(gtk_builder_get_object(dialog->priv->xml, "label54"));
-        gtk_label_set_xalign(label54, 0.0);
-        gtk_label_set_xalign(title_name, 0.05);
-        gtk_label_set_xalign(title_status, 0.1);
-
         button = GTK_WIDGET (gtk_builder_get_object (dialog->priv->xml,
                                                      CAPPLET_ADD_WIDGET_NAME));
         dialog->priv->add_button = button;
