@@ -1044,7 +1044,7 @@ update_card (GvcMixerControl      *control,
         const char *key;
         void *state;
 
-        g_debug ("Udpating card %s (index: %u driver: %s):",
+        g_debug ("Updating card %s (index: %u driver: %s):",
                  info->name, info->index, info->driver);
 
         for (i = 0; i < info->n_profiles; i++) {
@@ -1781,7 +1781,7 @@ gvc_mixer_new_pa_context (GvcMixerControl *self)
                           self->priv->name);
         pa_proplist_sets (proplist,
                           PA_PROP_APPLICATION_ID,
-                          "org.mate.VolumeControl");
+                          "org.ukui.VolumeControl");
         pa_proplist_sets (proplist,
                           PA_PROP_APPLICATION_ICON_NAME,
                           "multimedia-volume-control");
