@@ -63,7 +63,7 @@ G_DEFINE_TYPE (GvcSoundThemeChooser, gvc_sound_theme_chooser, GTK_TYPE_VBOX)
 #define EVENT_SOUNDS_KEY           "event-sounds"
 #define INPUT_SOUNDS_KEY           "input-feedback-sounds"
 #define SOUND_THEME_KEY            "theme-name"
-#define KEY_MARCO_SCHEMA           "org.mate.Marco.general"
+#define KEY_MARCO_SCHEMA           "org.gnome.desktop.wm.preferences"
 #define AUDIO_BELL_KEY             "audible-bell"
 
 #define DEFAULT_ALERT_ID        "__default"
@@ -526,6 +526,8 @@ populate_model_from_dir (GvcSoundThemeChooser *chooser,
                 populate_model_from_file (chooser, model, path);
                 g_free (path);
         }
+
+        g_dir_close (d);
 }
 
 static gboolean
@@ -757,7 +759,7 @@ play_preview_for_path (GvcSoundThemeChooser *chooser,
                                                 CA_PROP_CANBERRA_XDG_THEME_NAME, parent_theme,
                                                 CA_PROP_EVENT_DESCRIPTION, _("Testing event sound"),
                                                 CA_PROP_CANBERRA_CACHE_CONTROL, "never",
-                                                CA_PROP_APPLICATION_ID, "org.mate.VolumeControl",
+                                                CA_PROP_APPLICATION_ID, "org.ukui.VolumeControl",
 #ifdef CA_PROP_CANBERRA_ENABLE
                                                 CA_PROP_CANBERRA_ENABLE, "1",
 #endif
@@ -768,7 +770,7 @@ play_preview_for_path (GvcSoundThemeChooser *chooser,
                                                 CA_PROP_EVENT_ID, "bell-window-system",
                                                 CA_PROP_EVENT_DESCRIPTION, _("Testing event sound"),
                                                 CA_PROP_CANBERRA_CACHE_CONTROL, "never",
-                                                CA_PROP_APPLICATION_ID, "org.mate.VolumeControl",
+                                                CA_PROP_APPLICATION_ID, "org.ukui.VolumeControl",
 #ifdef CA_PROP_CANBERRA_ENABLE
                                                 CA_PROP_CANBERRA_ENABLE, "1",
 #endif
@@ -780,7 +782,7 @@ play_preview_for_path (GvcSoundThemeChooser *chooser,
                                         CA_PROP_MEDIA_FILENAME, id,
                                         CA_PROP_EVENT_DESCRIPTION, _("Testing event sound"),
                                         CA_PROP_CANBERRA_CACHE_CONTROL, "never",
-                                        CA_PROP_APPLICATION_ID, "org.mate.VolumeControl",
+                                        CA_PROP_APPLICATION_ID, "org.ukui.VolumeControl",
 #ifdef CA_PROP_CANBERRA_ENABLE
                                         CA_PROP_CANBERRA_ENABLE, "1",
 #endif
